@@ -19,8 +19,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-;; 02111-1307, USA.
+;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA
 
 ;;; Commentary:
 
@@ -514,6 +513,7 @@ Acts on the region or places point where it needs to be."
   (set (make-local-variable 'comment-start) ";")
   (set (make-local-variable 'comment-start) "#")
   (set (make-local-variable 'comment-end) "\n")
+  (set (make-local-variable 'comment-end-skip) "[ \t]*\\(\\s>\\||#\\)")
   (set (make-local-variable 'skeleton-end-hook) nil) ; so the skeletons will not automatically go to a new line.
   (set (make-local-variable 'fill-column) '100);cause I was having problems with autofill.
   (set (make-local-variable 'indent-line-function) 'remind-indent-line)
