@@ -192,7 +192,7 @@ int DoRem(ParsePtr p)
 
     r = OK;
     if (ShouldTriggerReminder(&trig, &tim, dse, &err)) {
-	if ( (r=TriggerReminder(p, &trig, &tim, dse, 0)) ) {
+	if ( (r=TriggerReminder(p, &trig, &tim, dse, 0, NULL)) ) {
 	    FreeTrig(&trig);
 	    return r;
 	}
@@ -910,7 +910,7 @@ static int ParseScanFrom(ParsePtr s, Trigger *t, int type)
 /*  Trigger the reminder if it's a RUN or MSG type.            */
 /*                                                             */
 /***************************************************************/
-int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued)
+int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued, DynamicBuffer *output)
 {
     int r, y, m, d;
     char PrioExpr[VAR_NAME_LEN+25];
@@ -977,7 +977,7 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queue
     }
 /* If it's a MSG-type reminder, and no -k option was used, issue the banner. */
     if ((t->typ == MSG_TYPE || t->typ == MSF_TYPE) 
-	&& !DidMsgReminder && !NextMode && !msg_command) {
+	&& !DidMsgReminder && !NextMode && !msg_command && !is_queued) {
         DidMsgReminder = 1;
 	if (!DoSubstFromString(DBufValue(&Banner), &buf,
 			       DSEToday, NO_TIME) &&
@@ -1044,11 +1044,18 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queue
  	    return E_NO_MEM;
  	}
 
- 	printf("%s%s%s\n", DBufValue(&calRow), DBufValue(&pre_buf), DBufValue(&buf));
+        r = OK;
+        if (output) {
+            if (DBufPuts(output, DBufValue(&calRow)) != OK) r = E_NO_MEM;
+            if (DBufPuts(output, DBufValue(&pre_buf)) != OK) r = E_NO_MEM;
+            if (DBufPuts(output, DBufValue(&buf)) != OK) r = E_NO_MEM;
+        } else {
+            printf("%s%s%s\n", DBufValue(&calRow), DBufValue(&pre_buf), DBufValue(&buf));
+        }
 	DBufFree(&buf);
 	DBufFree(&pre_buf);
 	DBufFree(&calRow);
-	return OK;
+	return r;
     }
 
     /* Correct colors */
@@ -1144,23 +1151,27 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queue
     case MSG_TYPE:
     case PASSTHRU_TYPE:
 	if (msg_command) {
-	    DoMsgCommand(msg_command, DBufValue(&buf));
+	    DoMsgCommand(msg_command, DBufValue(&buf), is_queued);
 	} else {
-            /* Add a space before "NOTE endreminder" */
-            if (IsServerMode() && !strncmp(DBufValue(&buf), "NOTE endreminder", 16)) {
-                printf(" %s", DBufValue(&buf));
+            if (output) {
+                DBufPuts(output, DBufValue(&buf));
             } else {
-                printf("%s", DBufValue(&buf));
+                /* Add a space before "NOTE endreminder" */
+                if (IsServerMode() && !strncmp(DBufValue(&buf), "NOTE endreminder", 16)) {
+                    printf(" %s", DBufValue(&buf));
+                } else {
+                    printf("%s", DBufValue(&buf));
+                }
             }
 	}
 	break;
 
     case MSF_TYPE:
-	FillParagraph(DBufValue(&buf));
+	FillParagraph(DBufValue(&buf), output);
 	break;
 
     case RUN_TYPE:
-	System(DBufValue(&buf));
+	System(DBufValue(&buf), is_queued);
 	break;
 
     default: /* Unknown/illegal type? */
@@ -1387,7 +1398,7 @@ static int ParsePriority(ParsePtr s, Trigger *t)
 /*  Execute the '-k' command, escaping shell chars in message. */
 /*                                                             */
 /***************************************************************/
-int DoMsgCommand(char const *cmd, char const *msg)
+int DoMsgCommand(char const *cmd, char const *msg, int is_queued)
 {
     int r;
     int i, l;
@@ -1424,7 +1435,7 @@ int DoMsgCommand(char const *cmd, char const *msg)
     }
     r = OK;
 
-    System(DBufValue(&execBuffer));
+    System(DBufValue(&execBuffer), is_queued);
 
 finished:
     DBufFree(&buf);
