@@ -249,7 +249,7 @@ json_value * json_parse_ex (json_settings * settings,
    const json_char * end;
    json_value * top, * root, * alloc = 0;
    json_state state = { 0 };
-   long flags = 0;
+   long flags;
    double num_digits = 0, num_e = 0;
    double num_fraction = 0;
 
@@ -299,7 +299,7 @@ json_value * json_parse_ex (json_settings * settings,
 	 if (flags & flag_string)
 	 {
 	    if (!b)
-	    {  sprintf (error, "Unexpected EOF in string (at %d:%d)", line_and_col);
+	    {  sprintf (error, "Unexpected EOF in string (at %u:%u)", line_and_col);
 	       goto e_failed;
 	    }
 
@@ -325,7 +325,7 @@ json_value * json_parse_ex (json_settings * settings,
 			(uc_b3 = hex_value (*++ state.ptr)) == 0xFF ||
 			(uc_b4 = hex_value (*++ state.ptr)) == 0xFF)
 		    {
-			sprintf (error, "Invalid character value `%c` (at %d:%d)", b, line_and_col);
+			sprintf (error, "Invalid character value `%c` (at %u:%u)", b, line_and_col);
 			goto e_failed;
 		    }
 
@@ -342,7 +342,7 @@ json_value * json_parse_ex (json_settings * settings,
 			    (uc_b3 = hex_value (*++ state.ptr)) == 0xFF ||
 			    (uc_b4 = hex_value (*++ state.ptr)) == 0xFF)
 			{
-			    sprintf (error, "Invalid character value `%c` (at %d:%d)", b, line_and_col);
+			    sprintf (error, "Invalid character value `%c` (at %u:%u)", b, line_and_col);
 			    goto e_failed;
 			}
 
@@ -472,7 +472,7 @@ json_value * json_parse_ex (json_settings * settings,
 	       if (flags & flag_block_comment)
 	       {
 		  if (!b)
-		  {  sprintf (error, "%d:%d: Unexpected EOF in block comment", line_and_col);
+		  {  sprintf (error, "%u:%u: Unexpected EOF in block comment", line_and_col);
 		     goto e_failed;
 		  }
 
@@ -488,12 +488,12 @@ json_value * json_parse_ex (json_settings * settings,
 	    else if (b == '/')
 	    {
 	       if (! (flags & (flag_seek_value | flag_done)) && top->type != json_object)
-	       {  sprintf (error, "%d:%d: Comment not allowed here", line_and_col);
+	       {  sprintf (error, "%u:%u: Comment not allowed here", line_and_col);
 		  goto e_failed;
 	       }
 
 	       if (++ state.ptr == end)
-	       {  sprintf (error, "%d:%d: EOF unexpected", line_and_col);
+	       {  sprintf (error, "%u:%u: EOF unexpected", line_and_col);
 		  goto e_failed;
 	       }
 
@@ -508,7 +508,7 @@ json_value * json_parse_ex (json_settings * settings,
 		     continue;
 
 		  default:
-		     sprintf (error, "%d:%d: Unexpected `%c` in comment opening sequence", line_and_col, b);
+		     sprintf (error, "%u:%u: Unexpected `%c` in comment opening sequence", line_and_col, b);
 		     goto e_failed;
 	       };
 	    }
@@ -526,7 +526,7 @@ json_value * json_parse_ex (json_settings * settings,
 
 	       default:
 
-		  sprintf (error, "%d:%d: Trailing garbage: `%c`",
+		  sprintf (error, "%u:%u: Trailing garbage: `%c`",
 			   state.cur_line, state.cur_col, b);
 
 		  goto e_failed;
@@ -545,7 +545,7 @@ json_value * json_parse_ex (json_settings * settings,
 		  if (top && top->type == json_array)
 		     flags = (flags & ~ (flag_need_comma | flag_seek_value)) | flag_next;
 		  else
-		  {  sprintf (error, "%d:%d: Unexpected ]", line_and_col);
+		  {  sprintf (error, "%u:%u: Unexpected ]", line_and_col);
 		     goto e_failed;
 		  }
 
@@ -561,7 +561,7 @@ json_value * json_parse_ex (json_settings * settings,
 		     }
 		     else
 		     {
-			sprintf (error, "%d:%d: Expected , before %c",
+			sprintf (error, "%u:%u: Expected , before %c",
 				 state.cur_line, state.cur_col, b);
 
 			goto e_failed;
@@ -576,7 +576,7 @@ json_value * json_parse_ex (json_settings * settings,
 		     }
 		     else
 		     {
-			sprintf (error, "%d:%d: Expected : before %c",
+			sprintf (error, "%u:%u: Expected : before %c",
 				 state.cur_line, state.cur_col, b);
 
 			goto e_failed;
@@ -702,7 +702,7 @@ json_value * json_parse_ex (json_settings * settings,
 			   continue;
 			}
 			else
-			{  sprintf (error, "%d:%d: Unexpected %c when seeking value", line_and_col, b);
+			{  sprintf (error, "%u:%u: Unexpected %c when seeking value", line_and_col, b);
 			   goto e_failed;
 			}
 		  };
@@ -722,7 +722,7 @@ json_value * json_parse_ex (json_settings * settings,
 		  case '"':
 
 		     if (flags & flag_need_comma)
-		     {  sprintf (error, "%d:%d: Expected , before \"", line_and_col);
+		     {  sprintf (error, "%u:%u: Expected , before \"", line_and_col);
 			goto e_failed;
 		     }
 
@@ -747,7 +747,7 @@ json_value * json_parse_ex (json_settings * settings,
 		     }
 		     /* FALLTHROUGH */
 		  default:
-		     sprintf (error, "%d:%d: Unexpected `%c` in object", line_and_col, b);
+		     sprintf (error, "%u:%u: Unexpected `%c` in object", line_and_col, b);
 		     goto e_failed;
 	       };
 
@@ -765,7 +765,7 @@ json_value * json_parse_ex (json_settings * settings,
 		     if (! (flags & flag_num_e))
 		     {
 			if (flags & flag_num_zero)
-			{  sprintf (error, "%d:%d: Unexpected `0` before `%c`", line_and_col, b);
+			{  sprintf (error, "%u:%u: Unexpected `0` before `%c`", line_and_col, b);
 			   goto e_failed;
 			}
 
@@ -814,7 +814,7 @@ json_value * json_parse_ex (json_settings * settings,
 	       else if (b == '.' && top->type == json_integer)
 	       {
 		  if (!num_digits)
-		  {  sprintf (error, "%d:%d: Expected digit before `.`", line_and_col);
+		  {  sprintf (error, "%u:%u: Expected digit before `.`", line_and_col);
 		     goto e_failed;
 		  }
 
@@ -831,7 +831,7 @@ json_value * json_parse_ex (json_settings * settings,
 		  if (top->type == json_double)
 		  {
 		     if (!num_digits)
-		     {  sprintf (error, "%d:%d: Expected digit after `.`", line_and_col);
+		     {  sprintf (error, "%u:%u: Expected digit after `.`", line_and_col);
 			goto e_failed;
 		     }
 
@@ -857,11 +857,11 @@ json_value * json_parse_ex (json_settings * settings,
 	       else
 	       {
 		  if (!num_digits)
-		  {  sprintf (error, "%d:%d: Expected digit after `e`", line_and_col);
+		  {  sprintf (error, "%u:%u: Expected digit after `e`", line_and_col);
 		     goto e_failed;
 		  }
 
-		  top->u.dbl *= pow (10.0, (flags & flag_num_e_negative ? - num_e : num_e));
+		  top->u.dbl *= pow (10.0, ((flags & flag_num_e_negative) ? - num_e : num_e));
 	       }
 
 	       if (flags & flag_num_negative)
@@ -942,7 +942,7 @@ json_value * json_parse_ex (json_settings * settings,
 
 e_unknown_value:
 
-   sprintf (error, "%d:%d: Unknown value", line_and_col);
+   sprintf (error, "%u:%u: Unknown value", line_and_col);
    goto e_failed;
 
 e_alloc_failure:
@@ -952,7 +952,7 @@ e_alloc_failure:
 
 e_overflow:
 
-   sprintf (error, "%d:%d: Too long (caught overflow)", line_and_col);
+   sprintf (error, "%u:%u: Too long (caught overflow)", line_and_col);
    goto e_failed;
 
 e_failed:
