@@ -6,7 +6,7 @@
 /*  the data structures for OMITted dates.                     */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -32,7 +32,7 @@ static int PartialOmitArray[MAX_PARTIAL_OMITS];
 /* WeekdayOmits is declared in global.h */
 
 /* How many of each omit types do we have? */
-static int NumFullOmits, NumPartialOmits;
+int NumFullOmits, NumPartialOmits;
 
 /* The structure for saving and restoring OMIT contexts */
 typedef struct omitcontext {
@@ -445,6 +445,9 @@ int DoOmit(ParsePtr p)
             if (!BexistsIntArray(PartialOmitArray, NumPartialOmits, syndrome)) {
                 InsertIntoSortedArray(PartialOmitArray, NumPartialOmits, syndrome);
                 NumPartialOmits++;
+                if (NumPartialOmits == 366) {
+                    Wprint("You have OMITted everything!  The space-time continuum is at risk.");
+                }
             }
             if (mc == m[1] && dc == d[1]) {
                 break;
