@@ -38,7 +38,7 @@ int DoRem (ParsePtr p);
 int DoFlush (ParsePtr p);
 void DoExit (ParsePtr p);
 int ParseRem (ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals);
-int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued);
+int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued, DynamicBuffer *output);
 int ShouldTriggerReminder (Trigger *t, TimeTrig *tim, int dse, int *err);
 int DoSubst (ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse, int mode);
 int DoSubstFromString (char const *source, DynamicBuffer *dbuf, int dse, int tim);
@@ -118,7 +118,7 @@ void DestroyVars (int all);
 int PreserveVar (char const *name);
 int DoPreserve  (Parser *p);
 int DoSatRemind (Trigger *trig, TimeTrig *tt, ParsePtr p);
-int DoMsgCommand (char const *cmd, char const *msg);
+int DoMsgCommand (char const *cmd, char const *msg, int is_queued);
 int ParseNonSpaceChar (ParsePtr p, int *err, int peek);
 unsigned int HashVal (char const *str);
 int DateOK (int y, int m, int d);
@@ -142,7 +142,7 @@ int GetSysVar (char const *name, Value *val);
 int SetSysVar (char const *name, Value *val);
 void DumpSysVarByName (char const *name);
 int CalcMinsFromUTC (int dse, int tim, int *mins, int *isdst);
-void FillParagraph (char const *s);
+void FillParagraph (char const *s, DynamicBuffer *output);
 void LocalToUTC (int locdate, int loctime, int *utcdate, int *utctime);
 void UTCToLocal (int utcdate, int utctime, int *locdate, int *loctime);
 int MoonPhase (int date, int time);
@@ -168,7 +168,7 @@ void PrintJSONKeyPairString(char const *name, char const *val);
 void PrintJSONKeyPairDate(char const *name, int dse);
 void PrintJSONKeyPairDateTime(char const *name, int dt);
 void PrintJSONKeyPairTime(char const *name, int t);
-void System(char const *cmd);
+void System(char const *cmd, int queued);
 int ShellEscape(char const *in, DynamicBuffer *out);
 int AddGlobalOmit(int dse);
 void set_lat_and_long_from_components(void);
@@ -179,6 +179,7 @@ int GetTerminalBackground(void);
 char const *get_day_name(int wkday);
 char const *get_month_name(int mon);
 
+void set_cloexec(int fd);
 int push_call(char const *filename, char const *func, int lineno);
 void clear_callstack(void);
 int print_callstack(FILE *fp);
@@ -190,5 +191,5 @@ void WriteJSONTimeTrigger(TimeTrig const *tt);
 #define _XOPEN_SOURCE 600
 #include <wctype.h>
 #include <wchar.h>
-void PutWideChar(wchar_t const wc);
+void PutWideChar(wchar_t const wc, DynamicBuffer *output);
 #endif
