@@ -136,7 +136,7 @@ void IssueSortedReminders(void)
 	switch(cur->typ) {
 	case MSG_TYPE:
 	    if (MsgCommand && *MsgCommand) {
-		DoMsgCommand(MsgCommand, cur->text);
+		DoMsgCommand(MsgCommand, cur->text, 0);
             } else {
 		if (cur->trigdate != olddate) {
 		    IssueSortBanner(cur->trigdate);
@@ -151,11 +151,11 @@ void IssueSortedReminders(void)
                 IssueSortBanner(cur->trigdate);
                 olddate = cur->trigdate;
             }
-	    FillParagraph(cur->text);
+	    FillParagraph(cur->text, NULL);
 	    break;
 
 	case RUN_TYPE:
-	    System(cur->text);
+	    System(cur->text, 0);
 	    break;
 	}
 
