@@ -6,7 +6,7 @@
 /*  user- and system-defined variables.                        */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2024 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -167,6 +167,13 @@ static int latitude_func(int do_set, Value *val)
     return latitude_longitude_func(do_set, val, &Latitude, -90.0, 90.0);
 }
 
+static int terminal_bg_func(int do_set, Value *val)
+{
+    UNUSED(do_set);
+    val->type = INT_TYPE;
+    val->v.val = GetTerminalBackground();
+    return OK;
+}
 
 static int trig_date_func(int do_set, Value *val)
 {
@@ -525,7 +532,9 @@ int DoSet (Parser *p)
     int r;
 
     DynamicBuffer buf;
+    DynamicBuffer buf2;
     DBufInit(&buf);
+    DBufInit(&buf2);
 
     r = ParseIdentifier(p, &buf);
     if (r) return r;
@@ -541,6 +550,13 @@ int DoSet (Parser *p)
 	return r;
     }
 
+    r = ParseToken(p, &buf2);
+    if (r) return r;
+    if (DBufLen(&buf2)) {
+        DBufFree(&buf2);
+        return E_EXPECTING_EOL;
+    }
+    DBufFree(&buf2);
     if (*DBufValue(&buf) == '$') r = SetSysVar(DBufValue(&buf)+1, &v);
     else r = SetVar(DBufValue(&buf), &v);
     if (buf.len > VAR_NAME_LEN) {
@@ -762,10 +778,14 @@ typedef struct {
     char modifiable;
     int type;
     void *value;
-    int min;
+    int min; /* Or const-value */
     int max;
 } SysVar;
 
+/* Macro to access "min" but as a constval.  Just to make source more
+   readable */
+#define constval min
+
 /* If the type of a sys variable is STR_TYPE, then min is redefined
    to be a flag indicating whether or not the value has been malloc'd. */
 #define been_malloced min
@@ -792,7 +812,7 @@ static SysVar SysVarArr[] = {
     {"DefaultColor",   1,  SPECIAL_TYPE, default_color_func,   0,      0 },
     {"DefaultPrio",    1,  INT_TYPE,     &DefaultPrio,         0,      9999 },
     {"DefaultTDelta",  1,  INT_TYPE,     &DefaultTDelta,       0,      1440 },
-    {"DeltaOffset",    0,  INT_TYPE,     &DeltaOffset,         0,      0 },
+    {"DeltaOverride",  0,  INT_TYPE,     &DeltaOverride,         0,      0 },
     {"DontFork",       0,  INT_TYPE,     &DontFork,            0,      0 },
     {"DontQueue",      0,  INT_TYPE,     &DontQueue,           0,      0 },
     {"DontTrigAts",    0,  INT_TYPE,     &DontIssueAts,        0,      0 },
@@ -825,6 +845,9 @@ static SysVar SysVarArr[] = {
     {"LongMin",        1,  SPECIAL_TYPE, longmin_func,         0,      0 },
     {"LongSec",        1,  SPECIAL_TYPE, longsec_func,         0,      0 },
     {"March",          1,  STR_TYPE,     &DynamicMonthName[2], 0,      0 },
+    {"MaxFullOmits",   0,  CONST_INT_TYPE, NULL,        MAX_FULL_OMITS, 0},
+    {"MaxLateMinutes", 1,  INT_TYPE,     &MaxLateMinutes,      0,      1440 },
+    {"MaxPartialOmits",0,  CONST_INT_TYPE, NULL,    MAX_PARTIAL_OMITS, 0},
     {"MaxSatIter",     1,  INT_TYPE,     &MaxSatIter,          10,     ANY },
     {"MaxStringLen",   1,  INT_TYPE,     &MaxStringLen,        -1,     ANY },
     {"May",            1,  STR_TYPE,     &DynamicMonthName[4], 0,      0 },
@@ -835,10 +858,13 @@ static SysVar SysVarArr[] = {
     {"NextMode",       0,  INT_TYPE,     &NextMode,            0,      0 },
     {"November",       1,  STR_TYPE,     &DynamicMonthName[10],0,      0 },
     {"Now",            1,  STR_TYPE,     &DynamicNow,          0,      0 },
+    {"NumFullOmits",   0,  INT_TYPE,     &NumFullOmits,        0,      0 },
+    {"NumPartialOmits",0,  INT_TYPE,     &NumPartialOmits,     0,      0 },
     {"NumQueued",      0,  INT_TYPE,     &NumQueued,           0,      0 },
     {"NumTrig",        0,  INT_TYPE,     &NumTriggered,        0,      0 },
     {"October",        1,  STR_TYPE,     &DynamicMonthName[9], 0,      0 },
     {"On",             1,  STR_TYPE,     &DynamicOn,           0,      0 },
+    {"ParseUntriggered", 1, INT_TYPE,    &ParseUntriggered,    0,      1 },
     {"Pm",             1,  STR_TYPE,     &DynamicPm,           0,      0 },
     {"PrefixLineNo",   0,  INT_TYPE,     &DoPrefixLineNo,      0,      0 },
     {"PSCal",          0,  INT_TYPE,     &PsCal,               0,      0 },
@@ -855,7 +881,7 @@ static SysVar SysVarArr[] = {
     {"SysInclude",     0,  STR_TYPE,     &SysDir,              0,      0 },
     {"T",              0,  SPECIAL_TYPE, trig_date_func,       0,      0 },
     {"Td",             0,  SPECIAL_TYPE, trig_day_func,        0,      0 },
-    {"TerminalBackground", 0, INT_TYPE,  &TerminalBackground,  0,      0 },
+    {"TerminalBackground", 0, SPECIAL_TYPE,  terminal_bg_func, 0,      0 },
     {"Thursday",       1,  STR_TYPE,     &DynamicDayName[3],   0,      0 },
     {"TimeSep",        1,  SPECIAL_TYPE, time_sep_func,        0,      0 },
     {"Tm",             0,  SPECIAL_TYPE, trig_mon_func,        0,      0 },
@@ -893,13 +919,13 @@ int SetSysVar(char const *name, Value *value)
     int r;
     SysVar *v = FindSysVar(name);
     if (!v) return E_NOSUCH_VAR;
-    if (v->type != SPECIAL_TYPE &&
-	v->type != value->type) return E_BAD_TYPE;
     if (!v->modifiable) {
 	Eprint("%s: `$%s'", ErrMsg[E_CANT_MODIFY], name);
 	return E_CANT_MODIFY;
     }
 
+    if (v->type != SPECIAL_TYPE &&
+	v->type != value->type) return E_BAD_TYPE;
     if (v->type == SPECIAL_TYPE) {
 	SysVarFunc f = (SysVarFunc) v->value;
 	r = f(1, value);
@@ -940,6 +966,11 @@ int GetSysVar(char const *name, Value *val)
 
     val->type = ERR_TYPE;
     if (!v) return E_NOSUCH_VAR;
+    if (v->type == CONST_INT_TYPE) {
+        val->v.val = v->constval;
+        val->type = INT_TYPE;
+        return OK;
+    }
     if (v->type == SPECIAL_TYPE) {
 	SysVarFunc f = (SysVarFunc) v->value;
 	return f(0, val);
@@ -1033,7 +1064,9 @@ static void DumpSysVar(char const *name, const SysVar *v)
     if (name) strcat(buffer, name); else strcat(buffer, v->name);
     fprintf(ErrFp, "%16s  ", buffer);
     if (v) {
-	if (v->type == SPECIAL_TYPE) {
+        if (v->type == CONST_INT_TYPE) {
+            fprintf(ErrFp, "%d\n", v->constval);
+        } else if (v->type == SPECIAL_TYPE) {
 	    SysVarFunc f = (SysVarFunc) v->value;
 	    f(0, &vtmp);
 	    PrintValue(&vtmp, ErrFp);
